OC.L10N.register(
    "lib",
    {
    "Help" : "အကူအညီ",
    "Users" : "သုံးစွဲသူ",
    "Admin" : "အက်ဒမင်",
    "today" : "ယနေ့",
    "yesterday" : "မနေ့က",
    "last month" : "ပြီးခဲ့သောလ",
    "last year" : "မနှစ်က",
    "seconds ago" : "စက္ကန့်အနည်းငယ်က",
    "web services under your control" : "သင်၏ထိန်းချုပ်မှု့အောက်တွင်ရှိသော Web services",
    "Authentication error" : "ခွင့်ပြုချက်မအောင်မြင်",
    "Could not find category \"%s\"" : "\"%s\"ခေါင်းစဉ်ကို ရှာမတွေ့ပါ",
    "Apps" : "Apps"
},
"nplurals=1; plural=0;");
